package com.zd.laboratory.service;

import java.util.List;
import com.zd.laboratory.domain.LabExitLight;
import com.zd.laboratory.domain.vo.LabExitLightVO;

/**
 * 逃生指引灯Service接口
 *
 * @author zd
 * @date 2022-01-25
 */
public interface ILabExitLightService
{
    /**
     * 查询逃生指引灯
     *
     * @param id 逃生指引灯主键
     * @return 逃生指引灯
     */
    public LabExitLightVO selectLabExitLightById(Long id);

    /**
     * 查询逃生指引灯列表
     *
     * @param labExitLightVO 逃生指引灯
     * @return 逃生指引灯集合
     */
    public List<LabExitLightVO> selectLabExitLightList(LabExitLightVO labExitLightVO);

    /**
     * 新增逃生指引灯
     *
     * @param labExitLight 逃生指引灯
     * @return 结果
     */
    public int insertLabExitLight(LabExitLight labExitLight);

    /**
     * 修改逃生指引灯
     *
     * @param labExitLight 逃生指引灯
     * @return 结果
     */
    public int updateLabExitLight(LabExitLight labExitLight);

    /**
     * 批量删除逃生指引灯
     *
     * @param ids 需要删除的逃生指引灯主键集合
     * @return 结果
     */
    public int deleteLabExitLightByIds(Long[] ids);

    /**
     * 删除逃生指引灯信息
     *
     * @param id 逃生指引灯主键
     * @return 结果
     */
    public int deleteLabExitLightById(Long id);
}
