package com.zd.laboratory.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.zd.common.core.domain.per.PerFun;
import com.zd.common.core.domain.per.PerPrefix;
import com.zd.common.core.web.domain.ResultData;
import com.zd.laboratory.domain.vo.LabExitLightVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zd.common.log.annotation.Log;
import com.zd.common.log.enums.BusinessType;
import com.zd.common.security.annotation.PreAuthorize;
import com.zd.laboratory.domain.LabExitLight;
import com.zd.laboratory.service.ILabExitLightService;
import com.zd.common.core.web.controller.BaseController;
import com.zd.common.core.web.domain.AjaxResult;
import com.zd.common.core.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.zd.common.swagger.config.Knife4jConfiguration;

import com.zd.common.core.web.page.TableDataInfo;

/**
 * 逃生指引灯Controller
 *
 * @author zd
 * @date 2022-01-25
 */
@RestController
@Api(tags = "【逃生指引灯】")
//作者手动加入 ，在接口上加作者@ApiOperationSupport(author = "XXX")
@ApiSupport(author = Knife4jConfiguration.Author.CYL)
@RequestMapping("/light")
public class LabExitLightController extends BaseController
{
    @Autowired
    private ILabExitLightService labExitLightService;

    /**
     * 查询逃生指引灯列表
     */
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_LIGHT + PerFun.LIST)
    @GetMapping("/list")
    @ApiOperation(value = "查询逃生指引灯列表")
    public TableDataInfo<LabExitLightVO> list(LabExitLightVO labExitLightVO)
    {
        startPage();
        List<LabExitLightVO> list = labExitLightService.selectLabExitLightList(labExitLightVO);
        return getDataTable(list);
    }

    /**
     * 导出逃生指引灯列表
     */
    @ApiOperation(value = "导出逃生指引灯列表")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_LIGHT + PerFun.EXPORT)
    @Log(title = "逃生指引灯", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, LabExitLightVO labExitLightVO) throws IOException
    {
        List<LabExitLightVO> list = labExitLightService.selectLabExitLightList(labExitLightVO);
        ExcelUtil<LabExitLightVO> util = new ExcelUtil<LabExitLightVO>(LabExitLightVO.class);
        util.exportExcel(response, list, "逃生指引灯数据");
    }

    /**
     * 获取逃生指引灯详细信息
     */
    @ApiOperation(value = "获取逃生指引灯详细信息")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_LIGHT + PerFun.QUERY)
    @GetMapping(value = "/{id}")
    public ResultData<LabExitLightVO> getInfo(@PathVariable("id") Long id)
    {
        return ResultData.success(labExitLightService.selectLabExitLightById(id));
    }

    /**
     * 新增逃生指引灯
     */
    @ApiOperation(value = "新增逃生指引灯")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_LIGHT + PerFun.ADD)
    @Log(title = "逃生指引灯", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultData add(@RequestBody LabExitLight labExitLight)
    {
        return ResultData.result(labExitLightService.insertLabExitLight(labExitLight));
    }

    /**
     * 修改逃生指引灯
     */
    @ApiOperation(value = "修改逃生指引灯")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_LIGHT + PerFun.EDIT)
    @Log(title = "逃生指引灯", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultData edit(@RequestBody LabExitLight labExitLight)
    {
        return  ResultData.result(labExitLightService.updateLabExitLight(labExitLight));
    }

    /**
     * 删除逃生指引灯
     */
    @ApiOperation(value = "删除逃生指引灯")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_LIGHT + PerFun.REMOVE)
    @Log(title = "逃生指引灯", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public ResultData remove(@PathVariable Long[] ids)
    {
        return ResultData.result(labExitLightService.deleteLabExitLightByIds(ids));
    }
}
